import pathlib        # Python Pathlib - https://docs.python.org/3/library/pathlib.html

import appdirs      # AppDirs - https://github.com/ActiveState/appdirs
import wx           # wxPython - https://wxpython.org/


class AppConfig(wx.FileConfig):
    def __init__(self):
        app = wx.GetApp()

        # get the correct directory for saving settings
        self.path = pathlib.Path(
            appdirs.user_config_dir(
                app.constants.app_name,
                app.constants.vendor_name
            )
        )

        # make sure the directories exist
        self.path.mkdir(parents=True, exist_ok=True)

        # call parent init
        super().__init__(
            localFilename=str(self.path.resolve()) + "/config.ini",
            style=wx.CONFIG_USE_LOCAL_FILE
        )

        # set to record back our default values
        self.SetRecordDefaults(True)

        # init startup options
        self.ReadBool("startup/show_splash", True)
        self.ReadBool("startup/open_last_edited", True)

        # init general options
        self.ReadBool("options/auto-save-commit", True)
        self.ReadBool("options/commit-sounds", False)
        self.ReadBool("options/disable-scrolling", False)

        # init font options
        if app.constants.platform == "Darwin":
            default_font_size = 14
        else:
            default_font_size = 12
        self.ReadInt("view/font_size", default_font_size)

        # init statusbar options
        self.ReadBool("statusbar/show_word_count", True)
        self.ReadBool("statusbar/show_session_word_count", True)

        # init update values
        self.ReadInt("updates/interval", 2)
        self.ReadInt("updates/last_check", 0)

        # init window positions
        self.ReadInt("window/size_x", round(wx.DisplaySize()[1] * 0.75 * 1.3333))
        self.ReadInt("window/size_y", round(wx.DisplaySize()[1] * 0.75))
        self.ReadInt("window/pos_x", -1)
        self.ReadInt("window/pos_y", -1)
        self.ReadBool("window/is_maximized", False)
        self.ReadBool("window/is_fullscreen", False)

        # init recent documents
        self.Read("files/current", "")
        self.Read("files/recent", "")

        # save out
        self.Flush()
