import pathlib          # Python Pathlib - https://docs.python.org/3/library/pathlib.html

import wx               # wxPython - https://wxpython.org/


class RecentList:
    def __init__(self):
        # get app obj
        self.app = wx.GetApp()
        self._ = self.app.constants.translation.gettext

        # process the recent files into an array
        if self.app.config.Read("files/recent") != "":
            self.file_list = (
                self.app.config.Read("files/recent")
            ).split("|")
        else:
            self.file_list = []

    def update(self, window):
        # de-dupe and remove empties!
        self.file_list = [*set(self.file_list)]
        filter(None, self.file_list)

        # loop and remove non-files
        for idx, this_file in enumerate(self.file_list):
            this_file_obj = pathlib.Path(this_file)

            if (
                not pathlib.Path(this_file).is_file() or
                idx > 10 or str(window.file.path) == str(this_file_obj)
            ):
                self.file_list.remove(this_file)

        # write back to settings
        self.app.config.Write("files/recent", "|".join(self.file_list))

        # get existing menu
        menu_items = window.file_recent.GetMenuItems()

        # wipe it out!
        for item in menu_items:
            window.file_recent.DestroyItem(item.GetId())

        # set up a new menu array
        new_menu = []

        if len(self.file_list) <= 0:
            this_menu = wx.MenuItem(
                window.file_recent,
                wx.ID_IGNORE,
                self._(u"No documents"),
                wx.EmptyString,
                wx.ITEM_NORMAL
            )
            new_menu.append(this_menu)
        else:
            for idx, file in enumerate(self.file_list):
                file_obj = pathlib.Path(file)
                this_menu_item = wx.MenuItem(
                    window.file_recent,
                    idx + 10000,
                    file_obj.name,
                    wx.EmptyString,
                    wx.ITEM_NORMAL
                )
                window.Bind(
                    wx.EVT_MENU,
                    window.event_menu_file_recent_open,
                    id=this_menu_item.GetId()
                )
                new_menu.append(this_menu_item)

            new_menu.append(
                wx.MenuItem(
                    window.file_recent,
                    wx.ID_ANY,
                    "",
                    wx.EmptyString,
                    wx.ITEM_SEPARATOR
                )
            )

            reset_recent = wx.MenuItem(
                window.file_recent,
                wx.ID_ANY,
                self._("Clear List")
            )
            window.Bind(
                wx.EVT_MENU,
                window.event_menu_file_recent_reset,
                id=reset_recent.GetId()
            )
            new_menu.append(reset_recent)

        for this_item in new_menu:
            window.file_recent.Append(this_item)
            if this_item.GetId() == wx.ID_IGNORE:
                this_item.Enable(False)

        # save back
        self.app.config.Flush()

    def reset(self, window):
        self.file_list = []
        self.update(window)
