import markdown2            # Markdown2 - https://github.com/trentm/python-markdown2
import wx                   # wxPython - https://wxpython.org/
import webbrowser           # Python WebBrowser - https://docs.python.org/3/library/webbrowser.html

from commit.ui.commit_ui_design import AboutWin_Base    # local - about window design from wxFormBuilder
from commit.ui.htmldisplaywin import HtmlDisplayWin     # local - about window


class AboutWin(AboutWin_Base):
    def __init__(self, parent):
        # call parent init
        super().__init__(parent)

        # get app obj
        self.app = wx.GetApp()

        # init translations
        self._ = self.app.constants.translation.gettext
        _ = self._

        # window title
        self.SetTitle(_("About") + " " + self.app.constants.app_display_name)

        # title
        self.title_text.SetLabel(self.app.constants.app_display_name + ": " + self.app.constants.app_tagline)

        # byline
        self.byline_text.SetLabel(_("by") + " " + self.app.constants.app_credit)

        # version
        self.version_text.SetLabel(_("Version") + " " + str(self.app.constants.app_version))

        # product code
        self.product_code.SetLabel(self.app.constants.vendor_product_code)

        # website line
        self.website_link.SetLabel(_("Website"))

        self.Fit()
        self.Center()

    def do_launch_credits(self, event):
        # get the credits file
        with open("commit/assets/CREDITS.md") as credit_file:
            credit_content = credit_file.read()

        credit_modal = HtmlDisplayWin(
            self,
            title=self._("Credits and Acknowledgements"),
            html_content=markdown2.markdown(credit_content)
        )

        credit_modal.ShowModal()

    def do_launch_license(self, event):
        # get the credits file
        with open("commit/assets/LICENSE.md") as license_file:
            license_content = license_file.read()

        license_modal = HtmlDisplayWin(
            self,
            title=self._("Software License"),
            html_content=markdown2.markdown(license_content)
        )

        license_modal.ShowModal()

    def do_launch_website(self, event):
        webbrowser.open(wx.GetApp().constants.app_website)

    def event_cursor_link(self, event):
        self.SetCursor(
            wx.Cursor(
                wx.CURSOR_HAND
            )
        )

    def event_cursor_normal(self, event):
        self.SetCursor(
            wx.Cursor(
               wx.CURSOR_DEFAULT
            )
        )