import wx           # wxPython - https://wxpython.org/

from commit.ui.commit_ui_design import PrefsWin_Base   # local - about window design from wxFormBuilder


class PrefsWin(PrefsWin_Base):
    def __init__(self, parent):
        # call parent init
        super().__init__(parent)

        # get app obj
        self.app = wx.GetApp()
        app = self.app

        # init translations
        self._ = app.constants.translation.gettext

        # some platform-specific tweaks
        if self.app.constants.platform == "Darwin":
            self.staticline_top.Hide()
            self.staticline_bottom.Hide()

        # set values to match current settings
        self.pref_select_splash.SetValue(
            app.config.ReadBool("startup/show_splash")
        )
        self.pref_select_open_last.SetValue(
            app.config.ReadBool("startup/open_last_edited")
        )
        self.pref_select_saveoncommit.SetValue(
            app.config.ReadBool("options/auto-save-commit")
        )
        self.pref_select_soundoncommit.SetValue(
            app.config.ReadInt("options/commit-sounds")
        )
        self.pref_select_disablescroll.SetValue(
            app.config.ReadInt("options/disable-scrolling")
        )
        self.pref_select_fontsize.SetValue(
            app.config.ReadInt("view/font_size")
        )
        self.pref_select_wordcount.SetValue(
            app.config.ReadBool("statusbar/show_word_count")
        )
        self.pref_select_session_wordcount.SetValue(
            app.config.ReadBool("statusbar/show_session_word_count")
        )
        self.pref_select_update_interval.SetSelection(
            app.config.ReadInt("updates/interval")
        )

        self.do_prefs_font_change(wx.Event)

        self.Fit()
        self.Center()

    def do_prefs_font_change(self, event):
        # change the example font size
        current_font = self.pref_example_text.GetFont()
        current_font.SetPointSize(self.pref_select_fontsize.GetValue())
        self.pref_example_text.SetFont(current_font)
        self.pref_example_text.Fit()

    def do_update_check(self, event):
        # do the update check
        self.app.updater.do_update_check(self)

    def do_prefs_reset(self, event):
        _ = self._
        confirm_dialog = wx.MessageDialog(
            self,
            _("This will completely reset and then close the application."),
            _("Confirm Reset"),
            wx.OK | wx.CANCEL | wx.CANCEL_DEFAULT | wx.ICON_WARNING
        )
        confirm_result = confirm_dialog.ShowModal()

        if confirm_result == wx.ID_OK:
            self.app.config.DeleteAll()
            self.EndModal(wx.ID_NONE)
            self.GetParent().Destroy()

    def do_prefs_save(self, event):
        app = self.app

        # save the updated values
        app.config.WriteBool(
            "startup/show_splash",
            self.pref_select_splash.GetValue()
        )
        app.config.WriteBool(
            "startup/open_last_edited",
            self.pref_select_open_last.GetValue()
        )
        app.config.WriteBool(
            "options/auto-save-commit",
            self.pref_select_saveoncommit.GetValue()
        )
        app.config.WriteBool(
            "options/commit-sounds",
            self.pref_select_soundoncommit.GetValue()
        )
        app.config.WriteBool(
            "options/disable-scrolling",
            self.pref_select_disablescroll.GetValue()
        )
        app.config.WriteInt(
            "view/font_size",
            self.pref_select_fontsize.GetValue()
        )
        app.config.WriteBool(
            "statusbar/show_word_count",
            self.pref_select_wordcount.GetValue()
        )
        app.config.WriteBool(
            "statusbar/show_session_word_count",
            self.pref_select_session_wordcount.GetValue()
        )
        app.config.WriteInt(
            "updates/interval",
            self.pref_select_update_interval.GetSelection()
        )

        # save the modifications
        app.config.Flush()

        # close the prefs window
        self.EndModal(wx.ID_SAVE)
